pytilities.testing

Package pytilities :: Module testing |
[hide private]
[frames] | no frames]

# Module testing

source code

Test utilities

Functions | [hide private]
get_recursive_package_test(root, test_package) Get a test suite of all tests inside a package and its child packages | source code
run(test) Run test and print results to stderr | source code

Variables | [hide private]
| _logger = `logging.getLogger("pytilities.testing")`
| __package__ = ``'``pytilities``'``

Function Details | [hide private]

### get_recursive_package_test(root, test_package) | source code
Get a test suite of all tests inside a package and its child packages Parameters: `root`:: string absolute path of the top package's directory of this python program `test_package`:: string name of package to search in for tests, in dotted format, e.g. 'project.test' See the wiki for a usage example. Returns ::unittest.TestSuite

### run(test) | source code
Run test and print results to stderr Parameters: test the TestCase to run